@@ -57,7 +57,7 @@ mod xpath_functions;
 mod definitions;
 mod pretty_print;
 
-pub mod shim_filesystem;
+pub mod shim_filesystem; // really just for override_file_for_debugging_rules, but the config seems to throw it off
 pub use interface::*;
 
 #[cfg(test)]
